@@ -1,7 +1,8 @@
 from .dnn import DNN
 from .multidnn import MultiDNN
+import tensorflow as tf
 
-__version__ = "0.3.5.19"
+__version__ = "0.4.0"
 
 def subprocess (train_func, *args):
     from multiprocessing import Pool
