@@ -328,6 +328,8 @@ class DNN:
             return
         summary = tf.Summary()
         for k, v in feed_dict.items ():
+            if not isinstance (v, (float, int)):
+                continue
             summary.value.add (tag = k , simple_value = v)
         if not self.on_ftest and writer not in self.writers:
             self.make_writers (writer)
@@ -985,13 +987,14 @@ class DNN:
 
     # helpers ------------------------------------------------------------------
     def l1 (self, scale):
-        return tf.contrib.layers.l1_regularizer (scale)
+        return tf.keras.regularizers.l1 (scale)
 
     def l2 (self, scale):
-        return tf.contrib.layers.l2_regularizer (scale)
+        # return tf.contrib.layers.l2_regularizer (scale)
+        return tf.keras.regularizers.l2 (scale)
 
     def l12 (self, scale_l1, scale_l2):
-        return tf.contrib.layers.l1_l2_regularizer (scale_l1, scale_l2)
+        return tf.keras.regularizers.l1_l2 (scale_l1, scale_l2)
 
     def max_norm (self, threshold, axes = 1):
         def max_norm_ (weights):
